@@ -12,7 +12,7 @@ use DBI;
 use Exception::Class::DBI;
 
 
-our $VERSION = '0.031';
+our $VERSION = '0.021';
 
 
 =head1 NAME
@@ -33,7 +33,7 @@ It is often convenient to lump articles together in categories. People do that t
 =cut
 
 AxKit::App::TABOO::Data::Category->elementorder("catname, name, type, uri, description");
-AxKit::App::TABOO::Data::Category->dbfrom("categories");
+AxKit::App::TABOO::Data::Category->selectquery("SELECT * FROM categories WHERE catname=?");
 
 =head1 METHODS
 
@@ -45,6 +45,27 @@ This class implements only one method, in addition to the constructor, the rest
 
 The constructor. Nothing special.
 
+=item C<all_of_type($type)>
+
+This method will return an arrayref containing the catnames of all categories of type C<$type>. This is a bit unelegant, since the typical use is to first call it on an object just created, then create an array containing Category objects based on it, but I didn't find a better solution right now... 
+
+
+
+=cut
+
+sub all_of_type {
+  my $self = shift;
+  my $type = shift;
+  my $dbh = DBI->connect($self->dbstring(), 
+			 $self->dbuser(), 
+			 $self->dbpasswd(),  
+			 { PrintError => 0,
+			   RaiseError => 0,
+			   HandleError => Exception::Class::DBI->handler
+			 });
+  return $dbh->selectcol_arrayref("SELECT catname FROM categories WHERE type=?", {}, $type);
+}
+
 
 =item C<load_name($catname)>
 
@@ -156,7 +177,5 @@ sub new {
 See L<AxKit::App::TABOO>.
 
 =cut
-
+    
 1;
-
-
